geom_weekly_timeslots: Construct geom_weekly_timeslots function
Description
Construct geom_weekly_timeslots function
Usage
geom_weekly_timeslots(mapping = NULL, data = NULL, ...)
Arguments
mapping
Set of aesthetic mappings created by aes() or
aes_(). If specified and inherit.aes = TRUE (the
default), it is combined with the default mapping at the top level of the
plot. You must supply mapping if there is no plot mapping.
Other arguments passed on to layer(). These are
often aesthetics, used to set an aesthetic to a fixed value, like
colour = "red" or size = 3. They may also be parameters
to the paired geom/stat.